#
# spec file for package python-apptools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         X_display         ":98"
%define         skip_python2      1
%ifarch ppc ppc64 ppc64le s390x
%bcond_with     test
%else
%bcond_without  test
%endif
Name:           python-apptools
Version:        5.3.0
Release:        1.2
Summary:        Application tools in Python
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
License:        BSD-3-Clause AND LGPL-2.1-only AND LGPL-3.0-only
URL:            https://github.com/enthought/apptools
Source:         https://files.pythonhosted.org/packages/source/a/apptools/apptools-%{version}.tar.gz
BuildRequires:  %{python_module configobj}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traits}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-configobj
Requires:       python-traits
Recommends:     python-pandas
Recommends:     python-tables
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tables}
BuildRequires:  %{python_module traitsui}
BuildRequires:  xorg-x11-server
%endif
%python_subpackages

%description
The apptools project includes a set of packages that Enthought has found
useful in creating a number of applications.  They implement functionality
that is commonly needed by many applications.

Part of the Enthought Tool Suite (ETS).

%prep
%autosetup -p1 -n apptools-%{version}

%build
%python_build
# Remove duplicates now so we can let rpm install it later
%fdupes examples/

%install
%python_install
%{python_expand $python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/apptools/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/apptools/
%fdupes %{buildroot}%{$python_sitelib}
}

%if %{with test}
%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

%pyunittest -v
%endif

%files %{python_files}
%doc README.rst CHANGES.txt
%doc examples/
%license LICENSE.txt image_LICENSE*.txt
%{python_sitelib}/apptools/
%{python_sitelib}/apptools-%{version}-py*.egg-info

%changelog
* Thu Aug 22 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- Update to 5.3.0:
  * Drop support for Python 3.7. (#339)
  * Replaced uses of ``numpy.alltrue``, for compatibility with NumPy 2.0. (#341)
  * Don't write to preferences on ``PreferencesHelper`` creation. (#343)
  * Fix a test that was broken in the presence of Mayavi / TVTK. (#352)
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 5.2.1:
  * Fix StatePickler for Python 3.11.
  * Add encoding as an attribute for LogFileHandler
    initialization
- drop python-311.patch (upstream)
* Thu Mar  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch, to support python3.11 gh#enthought/apptools#328
- Remove python310.patch, not needed anymore
- Update to version 5.2.0
  * Replace some uses of on_trait_change and depends_on with observe.
  * (#285, #289)
  * Use importlib.resources in preference to importlib_resources
  * on new enough Python versions. (#284)
  * Replace eval with ast.literal_eval in apptools.preferences.
  * (#299)
  * Use context managers to handle locks in apptools.preferences. (#306)
  * Fix test failures due to collections.abc changes in Python 3.10. (#313)
  * Remove a redundant elif branch in preference_binding. (#298)
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.1.0
  * Modules in the apptools.undo subpackage are modified to import
    from pyface.undo rather than redefining the classes.
    This should help ease the transition to using pyface.undo in
    place of the now deprecated apptool.undo.
  * Deprecations:
  * Import from pyface.undo.* instead of redefining classes in
    apptools.undo.*
  * Add module docstrings to the various api modules in apptools
    subpackages
- Add python310.patch
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 5.0.0
  * Support for Python versions < 3.6 have been dropped
  * Deprecate apptools.undo subpackage
  * Removed deprected subpackages
  * Remove appscripting subpackage
  * Remove template subpackage
  * Remove permission subpackage
  * Remove lru_cache subpackage
  * Remove the apptools.sweet_pickle subpackage.
    Users of sweet_pickle can in some cases transition to using
    apptools.persistence and pickle from the python standard library
  * Remove help subpackage
  * Remove NullHandler from apptools.logger
  * Remove apptools.logger.filtering_handler and
    apptools.logger.util submodules
  * Remove deprecated create_log_file_handler function
  * Remove use of apptools.type_manager from apptools.naming.
    Then, remove apptools.type_manager entirely. Finally, remove
    apptools.naming.adapter.
  * Remove apptools.persistence.spickle submodule
  * Remove apptools.naming.ui sub package
  * Update documentation for Preferences
  * Add a brief section to documentation for apptools.naming
  * Document the apptools.io and apptools.io.h5 sub packages
  * Fix a few broken links in the documentation
  * Fix SyntaxWarning in persistence.file_path
  * Fix container items change event being saved in preferences
  * Fix synchronizing preference trait with name _items
* Mon Feb  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Use pytest to run the testsuite, not nose.
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- Update to 4.5.0
  * Add missing `long_description_content_type` field in setup.
  * Remove use of `2to3`.
  * Use etstool for CI tasks. Setup travis macos and appveyor CI.
  * Temporarily change cwd when running tests.
  * Update broken imports.
  * Add `six` to requirements.
  * Remove one more use of the deprecated `set` method.
  * Use `trait_set` instead of the now deprecated `set` method.
  * Address one more numpy deprecation warning.
  * Address numpy deprecation warnings.
  * Test the package on Python 3.5, 3.6 on CI.
  * Fix mismatched pyface and traitsui requirements.
  * Drop support for Python 2.6.
  * Fix `state_pickler.dump` on Python 2.
  * Fix a few spelling mistakes in documentation.
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to 4.4.0
  * Apptools now works with Python-3.x. (#54)
  * Travis-ci support with testing on Python 2.6, 2.7 and 3.4. (#55)
* Sun May 24 2015 toddrme2178@gmail.com
- Update to 4.3.0
  * Apptools now have a changelog!
  * Preferences system defaults to utf-8 encoded string with ConfigObj providing
    better support for unicode in the PreferenceHelper (#41, #45).
  * Added a traitsified backport of Python 3's lru_cache (#39).
  * Added PyTables support to the io submodule (#19, #20, and #24 through #34).
  * Added a SelectionService for managing selections within an application (#15, #16, #17,
    [#23]).
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 4.2.1
  * no changelog
- Update source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.2.0
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Update to 4.1.0
* Thu Jan 12 2012 saschpe@suse.de
- Initial version
